# Miscellaneous Tools

**Note: all contents in this folder are miscellaneous and do not interact in any way with the rest of AeroSandbox. If you are trying to learn AeroSandbox, you should completely ignore this folder and move on.**

Some of them may use libraries which are not required as part of a base install of AeroSandbox, so many of these scripts won't work without extra installation on users' ends. Things in this folder may break, without warning - they are just gists stored in a common place for the benefit of a small core group of developers on various aircraft design projects at MIT.

Think of this as a "Gists" folder - random snippets and scripts from scientific computing work go here. Basically, these are a few snippets of "bundled software".